==> knfi_1.0.0.tar.gz: knfi/R/globalvars.R <==
#' The Korean and English names of the column names
#'
#' @description
#' The Korean and English names of the column names
#' 
#' @name col_name
#' 
"col_name"


#' National Forest Inventory data for Donghae-si, Gangwon-do, Republic of Korea for testing the function
#'
#' @description
#' National Forest Inventory data for Donghae-si, Gangwon-do, Republic of Korea for testing the function
#' 
#' @name nfi_donghae
#'
"nfi_donghae"


utils::globalVariables(c('.', 
                         "year", "deciduous_ba", "largetree_area", "tree_area", "BASAL_AREA", 
                         "num_clusterplot", "mean_DBH_temp", "mean_H_temp", "mean_dominant_H_temp",
                         "tree_temp", "basal_temp", "volume_temp", "tree_n_ha", "basal_m2_ha",
                         "value", "Richness", "Shannon", "Simpson", "Evenness",
                         "T_biomass", "AG_biomass", "carbon_stock", "co2_stock", 
                         "volume_m3", "biomass_ton", "AG_biomass_ton", "carbon_stock_tC", "co2_stock_tCO2",
                         "volume_m3_ha", "biomass_ton_ha", "AG_biomass_ton_ha", "carbon_stock_tC_ha", "co2_stock_tCO2_ha",
                         "w_volume_m3_ha", "w_biomass_ton_ha", "w_AG_biomass_ton_ha", "w_carbon_stock_tC_ha", "w_co2_stock_tCO2_ha", 
                         "var_volume_m3_ha", "var_biomass_ton_ha", "var_AG_biomass_ton_ha", "var_carbon_stock_tC_ha", "var_co2_stock_tCO2_ha", 
                         "se_volume_m3_ha", "se_biomass_ton_ha", "se_AG_biomass_ton_ha", "se_carbon_stock_tC_ha", "se_co2_stock_tCO2_ha",
                         "cwd_volume_m3_ha", "cwd_carbon_stock_tC_ha", "cwd_co2_stock_tCO2_ha",
                         "w_cwd_volume_m3_ha", "w_cwd_carbon_stock_tC_ha", "w_cwd_co2_stock_tCO2_ha",
                         "var_cwd_volume_m3_ha","var_cwd_carbon_stock_tC_ha", "var_cwd_co2_stock_tCO2_ha",
                         "se_cwd_volume_m3_ha", "se_cwd_carbon_stock_tC_ha", "se_cwd_co2_stock_tCO2_ha",
                         "geometry", "name","reorder","species", "importance.value" ,
                         "CCLCD", "CLST_PLOT", "CONDEC_CLASS_CD", "CYCLE", "DBH", "HT_EST", "INVYR", "NUMINDI",
                          "SP", "LARGEP_TREE", "SUB_PLOT", "TREECOUNT", "VOL", "VOL_EST", "WDY_PLNTS_TYP_CD", 
                          "domin_ba", "largetree", "do", "sgg", "emd", "clusterplot", "tables", "SIDO_CD", "SGG_CD","EMD_CD"
                         ))

==> knfi_1.0.1.tar.gz: knfi/R/globalvars.R <==
#' The Korean and English names of the column names
#'
#' @description
#' The Korean and English names of the column names
#' 
#' @name nfi_col
#' 
"nfi_col"


#' National Forest Inventory data for Donghae-si, Gangwon-do, Republic of Korea for testing the function
#'
#' @description
#' National Forest Inventory data for Donghae-si, Gangwon-do, Republic of Korea for testing the function
#' 
#' @name nfi_donghae
#'
"nfi_donghae"


utils::globalVariables(c('.', 
                         "year", "deciduous_ba", "largetree_area", "tree_area", "BASAL_AREA", "FORTYP_SUB",
                         "num_clusterplot", "mean_DBH_temp", "mean_H_temp", "mean_dominant_H_temp",
                         "tree_temp", "basal_temp", "volume_temp", "tree_n_ha", "basal_m2_ha",
                         "value", "Richness", "Shannon", "Simpson", "Evenness",
                         "T_biomass", "AG_biomass", "carbon_stock", "co2_stock", 
                         "volume_m3", "biomass_ton", "AG_biomass_ton", "carbon_stock_tC", "co2_stock_tCO2",
                         "volume_m3_ha", "biomass_ton_ha", "AG_biomass_ton_ha", "carbon_stock_tC_ha", "co2_stock_tCO2_ha",
                         "w_volume_m3_ha", "w_biomass_ton_ha", "w_AG_biomass_ton_ha", "w_carbon_stock_tC_ha", "w_co2_stock_tCO2_ha", 
                         "var_volume_m3_ha", "var_biomass_ton_ha", "var_AG_biomass_ton_ha", "var_carbon_stock_tC_ha", "var_co2_stock_tCO2_ha", 
                         "se_volume_m3_ha", "se_biomass_ton_ha", "se_AG_biomass_ton_ha", "se_carbon_stock_tC_ha", "se_co2_stock_tCO2_ha",
                         "cwd_volume_m3_ha", "cwd_carbon_stock_tC_ha", "cwd_co2_stock_tCO2_ha",
                         "w_cwd_volume_m3_ha", "w_cwd_carbon_stock_tC_ha", "w_cwd_co2_stock_tCO2_ha",
                         "var_cwd_volume_m3_ha","var_cwd_carbon_stock_tC_ha", "var_cwd_co2_stock_tCO2_ha",
                         "se_cwd_volume_m3_ha", "se_cwd_carbon_stock_tC_ha", "se_cwd_co2_stock_tCO2_ha",
                         "geometry", "name","reorder","species", "importance.value" ,
                         "CCLCD", "CLST_PLOT", "CONDEC_CLASS_CD", "CYCLE", "DBH", "HT_EST", "INVYR", "NUMINDI",
                          "SP", "LARGEP_TREE", "SUB_PLOT", "TREECOUNT", "VOL", "VOL_EST", "WDY_PLNTS_TYP_CD", 
                          "domin_ba", "largetree", "do", "sgg", "emd", "clusterplot", "tables", "SIDO_CD", "SGG_CD","EMD_CD"
                         ))
